;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
; Addressable 3 Channel Servo Driver
; zservo690a.asm
; 
; 24/10/2007
; picprojects.org  (c) 2010
;
;~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	#include "p16f690.inc"
	


   __CONFIG       _CP_OFF & _WDT_OFF & _BOR_OFF & _PWRTE_ON & _INTRC_OSC_NOCLKOUT & _MCLRE_ON & _CPD_OFF
          
          errorlevel -302     ; suppress banksel warning messages
          errorlevel -311     ; suppress HIGH operator warning messages

	cblock 0x20	 
		pwmCntr
		s1pos
		s2pos
		s3pos
		servo1NEW
		servo2NEW
		servo3NEW
		fadeNEW
		fadeRate
		fadeCounter
		fadeflag
		CntBase
		s1cnt
		s2cnt	
		s3cnt
		s1dir
		s2dir
		s3dir
	
		s1dif
		s2dif
		s3dif
		Chksum
		rxBufferBase:0
		rxPSD
		rxAddress
		rxData0	; red
		rxData1	; green
		rxData2	; blue
		rxData3	; fade
		rxChksum
		PSD
		Data0
		Data1
		Data2
		Data3
		servo1Latch
		servo2Latch
		servo3Latch
		fadeLatch
		column
		digit1
		digit2
		digit3
		shifter
		shiftCounter
		bcdLo
		bcdHi
		bin
		tvar1
		tvar2
		sw1timer
		sw2timer
		fpState
		activeTmrEn
		servoState
	endc

	cblock 0x70
		Wisr
		Sisr
		flags
		flags2
		savedBitRate
		myAddress
		myGroupRow
		myGroupCol
		eepromAddress
		eepromBitRate
		eepromInactive
		eepromValidate	
		sleepTimerLo
		sleepTimerHi
		saveFSR
	endc

#define   bank0     bcf       STATUS,RP0          ; Sel Bank 0
#define   bank1     bsf       STATUS,RP0          ; Sel Bank 1


#define   ServoPort	PORTC	; I/O port for LED PWM output
#define   activeDriveLevel	PORTB,4

#define	outEN	PORTC,7
#define	rClk	PORTC,6
#define	srClk	PORTC,4
#define	srDat	PORTC,5

drDig1bit	equ	5
drDig2bit	equ	4
drDig3bit	equ	3

#define	DigitPort	PORTC
#define	drDig1	DigitPort, drDig1bit	; msd left
#define	drDig2	DigitPort, drDig2bit	; middle
#define	drDig3	DigitPort, drDig3bit	; lsd right
#define	segDriveLevel	PORTB,6	


sw1bit	equ	5
sw2bit	equ	4
#define	swPort	PORTA
#define	sw1	swPort,sw1bit
#define	sw2	swPort,sw2bit

redLED	equ	0	; LED port bit
grnLED	equ	1	; LED port bit
bluLED	equ	2	; LED port bit

servo1	equ	0	; Servo Port bit
servo2	equ	1	; Servo Port bit
servo3	equ	2	; Servo Port bit

#define	heatSensor	PORTA,2	; LED overheat sensor

; define flag bits
rxNewCmd	equ	0	; New command received when flag set
rxNewCol	equ	1	; New colour data received when flag set
s1done	equ	2	; red fade active when flag set
s2done	equ	3	; green fade active when flag set
s3done	equ	4	; blue fade active when flag set
pirate	equ	5	; set flag if code modified detected
sw2Last	equ	6	; sw2 state last time
fpSave	equ	7	; front panel save flag
;define flags2 bits
sw1Last	equ	0	; sw2 state last time 
exitFP	equ	1	; front panel setup exit
LEDtype	equ	2	; 0 - common cathode | 1 = common anode
driveLevel	equ	3	; PWM Output active drive level
pwmShutdown	equ	4	; Set if PWM shutdown command active
	; set default bit rate for EEPROM intialisation
	; .0 = 1.2K
	; .1 = 2.4K
	; .2 = 9.6K
	; .3  = 19.2K
	; .4  = 38.4K
defaultBitRate	equ	.2

_resetVector	org 0x000
	nop
	nop
	goto	_main

	org 0x004
	#include	zservo_isr.inc		; isr code must be located here
	#include	zservo690a_cmdfuncs.inc	; lookup tables in cmdfuncs must be in page 0

_text1	dt "zcode690a release date 24/10/2007."
	dt "Addressable 3 channel servo driver for PIC 16F690."
	dt "This software is Copyright (C) 2007 Pete Griffiths."
	dt "picprojects.org"
	dt "For personal, non-commercial use only."
	dt "This software is provided 'as is', and without warranty of any kind, either express or implied."


	#include	zcode_serialRX.inc
	#include	zcode_eeprom.inc
	#include	zservo_move.inc
	#include	zservo690a_reset.inc
	#include	z690a_7seg.inc
	#include	zcode_switches.inc







	end	